@@ -7,6 +7,7 @@ fi
 
 #SVN_LOC=http://uv-desktop/svn/home/external/mosquitto
 SVN_LOC=http://192.168.15.50/svn/home/external/mosquitto
+MQVER=0.11.2
 SVNVER=`svn log $SVN_LOC --limit=1 | grep '^r' | sed 's/^r\([0-9]*\).*/\1/'`
 
 rm build-stamp configure-stamp
@@ -14,17 +15,21 @@ rm -rf ./mosquitto*
 rm -rf ./libmosquitto*
 
 # Cleanup from the first creation
-svn export $SVN_LOC mosquitto-0.9.1.$SVNVER
-pushd mosquitto-0.9.1.$SVNVER
+svn export $SVN_LOC mosquitto-$MQVER.$SVNVER
+pushd mosquitto-$MQVER.$SVNVER
 echo y | dh_make --createorig --single -e yuvraaj@gmail.com -c lgpl
 
 # Create everything for mosquitto
-cp build-files/postinst.mosquitto debian/postinst
 cp build-files/mosquitto.control debian/control
 cp build-files/mosquitto.rules debian/rules
 cp build-files/mosquitto.install debian/
+
+head -1 ./debian/changelog >dest.txt ; cat ./build-files/changelog >>dest.txt ; tail -2 ./debian/changelog | head -1 | sed 's/unknown/Yuvraaj Kelkar/g' >>dest.txt
+mv dest.txt ./debian/changelog
+
 dpkg-buildpackage -rfakeroot -sa -S
 dput -f $1-extras-builder ../mosquitto*.changes
+#dpkg-buildpackage -rfakeroot
 
 popd
 
