@@ -5,6 +5,10 @@
  * easily in restrictive environments by removing features.
  * ============================================================ */
 
+#ifndef CMAKE
+/* Only use the compile time options defined here from the standard Makefile. */
+
+
 /* Uncomment to compile with tcpd/libwrap support. */
 //#define WITH_WRAP
 
@@ -17,15 +21,6 @@
  * slightly less memory and CPU time. */
 #define WITH_MEMORY_TRACKING
 
-/* Compile with the ability to upgrade from old style sqlite persistent
- * databases to the new mosquitto format. This means a dependency on sqlite. It
- * isn't needed for new installations.
- * Not available on Windows.
- */
-#ifndef WIN32
-#define WITH_SQLITE_UPGRADE
-#endif
-
 /* Compile with persistent database support. This allows the broker to store
  * retained messages and durable subscriptions to a file periodically and on
  * shutdown. This is usually desirable (and is suggested by the MQTT spec), but
@@ -36,17 +31,24 @@
 #define WITH_PERSISTENCE
 #endif
 
-/* Compile with 32-bit integer database IDs instead of 64-bit integers. May be
- * useful in embedded systems or where be64toh()/htobe64() aren't available.
- * There is the potential for bad things to happen after the IDs wrap around.
- * This is especially likely if there are old retained messages. Note that at a
- * sustained rate of 10,000 messages/s, the database ID would overflow every 5
- * days. It is also worth noting that a broker compiled with 64-bit DB IDs will
- * not load a persistent database file saved from a 32-bit DB ID broker and
- * vice versa.
+/* Compile with bridge support included. This allow the broker to connect to
+ * other brokers and subscribe/publish to topics. You probably want to leave
+ * this included unless you want to save a very small amount of memory size and
+ * CPU time.
  */
-//#define WITH_32BIT_DBID
+#define WITH_BRIDGE
 
+/* Use the username/password and ACL checks defined in security_external.c
+ * This is empty by default, but gives a more straightforward way of adding
+ * support for existing username/password databases to mosquitto.
+ * Uncommenting without adding your own code to security_external.c will
+ * result in all access being denied.
+ * It also enables the db_* config options in mosquitto.conf.
+ * Get in touch with the authors if you need help adding support for your
+ * system.
+ */
+//#define WITH_EXTERNAL_SECURITY_CHECKS
+#endif
 
 /* ============================================================
  * Compatibility defines
@@ -57,14 +59,3 @@
 #define snprintf sprintf_s
 #define strcasecmp strcmpi
 #endif
-
-#ifdef WITH_SQLITE_UPGRADE
-#undef WITH_SQLITE_UPGRADE
-#endif
-
-#ifndef htobe64
-#define htobe64(x) (x)
-#endif
-#ifndef be64toh
-#define be64toh(x) (x)
-#endif
